@@ -55,14 +55,16 @@ def handle_firex_root_completion(sender, task, task_id, args, kwargs, **do_not_c
     sync = kwargs.get("sync", False)
 
     result_state = result.state
-    if sync and result_state != REVOKED and result_state != RETRY:  # Revoked can be in retry state with celery 5.1.0
+    is_revoked = result_state in [REVOKED, RETRY] # Revoked can be in retry state with celery 5.1.0
+    if sync and not is_revoked:
         logger.debug("Sync run has not been revoked. Cleanup skipped.")
         # Only if --sync run was revoked do we want to do the shutdown here; else it's done in firex.py
         return
 
     # Let this signal cause self-destruct
     submit_app.self_destruct(chain_details=(result, kwargs),
-                             reason=f'Root task completion ({result.state}) detected via postrun signal.')
+                             reason=f'Root task completion ({result.state}) detected via postrun signal.',
+                             run_revoked=is_revoked)
 
     logger.info("Root task post run signal completed")
 
